#!/bin/env python

import argparse
import subprocess
import sys
import urllib


common_args = ['gpg', '--batch', '--no-verbose']


def export_pubkey(args):
    """
    Export a public key
    """
    cmd_args = ['--armor'] if args.armor else ['--no-armor']
    cmd = ['--export'] + cmd_args + [urllib.unquote(args.local_user)]
    subprocess.check_call(common_args + cmd)


def detach_sign(args):
    """
    Create a detached signature
    """
    cmd_args = ['--armor'] if args.armor else ['--no-armor']
    cmd = ['--detach-sign', '--local-user', urllib.unquote(args.local_user)]
    subprocess.check_call(common_args + cmd + cmd_args)


def parse_args_or_exit(argv=None):
    """
    Parse command line options
    """
    parser = argparse.ArgumentParser(description="GnuPG signing proxy server")
    parser.add_argument("--armor", action='store_true')
    parser.add_argument("--no-armor", action='store_false', dest='armor')
    parser.add_argument("--export", action='store_const', const='export',
                        dest='action')
    parser.add_argument("--local-user", default=None)
    parser.add_argument("--detach-sign", "-b", action='store_const',
                        const='detach_sign', dest='action')

    return parser.parse_args(argv)


def main(argv):
    """
    Act on signing requests from clients
    """
    args = parse_args_or_exit(argv)

    if args.action == "export":
        export_pubkey(args)
    elif args.action == "detach_sign":
        detach_sign(args)
    else:
        raise RuntimeError("Unimplemented action: " + str(args.action))


def _main():
    """
    Entry point for setuptools CLI wrapper
    """
    main(sys.argv[1:])


# Entry point when run directly
if __name__ == "__main__":
    _main()
